@@ -1,11 +1,8 @@
 #!/usr/bin/perl
 
 package Mac::iTerm::LaunchPad;
-#
-# Open a new terminal in the Finder cwd
-#
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 1.2 $ =~ m/(\d+) \. (\d+)/x;
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.4 $ =~ m/(\d+) \. (\d+)/x;
 
 =head1 NAME
 
@@ -30,10 +27,14 @@ new-iterm - open a new iTerm window with one or more tabs
 	
 	---Aliases, predefined in code
 	% new-iterm music applications
+
 	
 	---Aliases, defined in your own ~/.new-iterm-aliases
 	% new-iterm foo bar baz
 	
+	---Any combination
+	% new-iterm finder /Users/brian/Dev music ~/Pictures foo
+	
 =head1 DESCRIPTION
 
 This script opens a new iTerm window and creates a tab for each
@@ -44,6 +45,16 @@ and uses that as the directory. The special directory named "finder"
 does the same thing (so you're stuck if you have a directory with that
 name: give it a different alias).
 
+=head2 Modulino
+
+This script is actually a modulino. It's a symlink to the
+C<Mac::iTerm::LaunchPad> module. That module figures out if it's run
+as a script or included as a module and does the right thing. If you
+want to change the program, edit the module.
+
+If you don't like that idea, use the included F<scripts/new-iterm>
+program which does the same thing without the symlink.
+
 =head2 Aliases
 
 You can define aliases in the F<~/.new-iterm-aliases> file. The file
@@ -103,6 +114,10 @@ You may use this program under the same terms as Perl itself.
 Some parts come from Chris Nandor and are noted in the source. They are
 available under the same license.
 
+=head1 SEE ALSO
+
+iTerm - http://iterm.sourceforge.net/
+
 =cut
 
 # defaults
